.. alhambra documentation master file, created by
   sphinx-quickstart on Thu Dec 14 18:55:21 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Alhambra Documentation
====================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   tutorial
   fileformat
   alhambra
   references



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
